@@ -95,10 +95,10 @@ fn load_impl(filename: &OsStr, filedata: &str, log_msgs: &mut Vec<String>, stric
         }
     }
     // build the a2l data structures from the tokens
-    let a2l_file = A2lFile::parse(&mut parser, context, 0);
-    if let Err(parse_error) = a2l_file {
-        return Err(parser.stringify_parse_error(&parse_error, true));
-    }
+    let a2l_file = match A2lFile::parse(&mut parser, context, 0) {
+        Ok(data) => data,
+        Err(parse_error) => return Err(parser.stringify_parse_error(&parse_error, true)),
+    };
 
     // make sure this is the end of the input, i.e. no additional data after the parsed data
     if let Some(token) = parser.peek_token() {
@@ -113,7 +113,7 @@ fn load_impl(filename: &OsStr, filedata: &str, log_msgs: &mut Vec<String>, stric
         }
     }
 
-    Ok(a2l_file.unwrap())
+    Ok(a2l_file)
 }
 
 
@@ -147,7 +147,7 @@ impl A2lFile {
 
     /// write this A2lFile object to the given file
     /// the banner will be placed inside a comment at the beginning of the file; "/*" an "*/" should not be part of the banner string
-    pub fn write(&self, filename: &str, banner: Option<&str>) -> Result<(), String> {
+    pub fn write(&self, filename: &OsStr, banner: Option<&str>) -> Result<(), String> {
         let mut outstr = "".to_string();
 
         let file_text = self.write_to_string();
@@ -156,14 +156,14 @@ impl A2lFile {
             outstr = format!("/* {} */", banner_text);
             // if the first line is empty (first charachter is \n), then the banner is placed on the empty line
             // otherwise a newline is added
-            if &file_text[0..1] != "\n" {
+            if !file_text.starts_with('\n') {
                 outstr.write_char('\n').unwrap();
             }
         }
         outstr.write_str(&file_text).unwrap();
 
         if let Err(err) = std::fs::write(filename, outstr) {
-            return Err(format!("Error while writing output {}: {}\n", filename, err.to_string()))
+            return Err(format!("Error while writing output {}: {}\n", filename.to_string_lossy(), err.to_string()))
         }
 
         Ok(())
